unit DAOvar;

interface
uses Windows, Forms, Sysutils;

type TTranslation = record
   langID  : WORD;
   charset  : WORD;
end;

Function GDataTypeEnum(PDataTypeEnum : Integer) : string;
Function GRelationAttributeEnum(PRelationAttributeEnum : Integer) : string;
Function GFieldAttributeEnum(PFieldAttributeEnum : Integer) : string;
Function GCollatingOrderEnum(PCollatingOrderEnum : Integer) : string;
Function GWorkspaceTypeEnum(PWorkspaceTypeEnum : Integer) : string;
Function GUpdateTypeEnum(PUpdateTypeEnum : Integer) : string;
Function GRecordStatusEnum(PRecordStatusEnum : Integer) : string;
Function GQueryDefTypeEnum(PQueryDefTypeEnum : Integer) : string;
Function GParameterDirectionEnum(PParameterDirectionEnum : Integer) : string;
Procedure GResetbtypes;
Function GetVersionNumber(VerString : string): String;

const
{ These are Node Captions }
  cnFields      = 'Fields';
  cnRelations   = 'Relations';
  cnQuerys      = 'Querys';
  cnEngine      = 'DBEngine3.5';
  cnWorkspaces  = 'Workspaces';
  cnParameters  = 'Parameters';
  cnDatabases   = 'Databases';
  cnUsers       = 'Users';
  cnGroups      = 'Groups';
  cnRecordsets  = 'Recordsets';
  cnTables      = 'Tables';
  cnIndexes     = 'Indexes';
  cnContainers  = 'Containers';
  cnDocuments   = 'Documents';

var
{ These are Booleans that match the Node Captions }
  isEngine      : Boolean;
  isWorkspaces  : Boolean;
  isDatabases   : Boolean;
  isTables      : Boolean;
  isIndexes     : Boolean;
  isRecordsets  : Boolean;
  isDocuments   : Boolean;
  isFields      : Boolean;
  isRelations   : Boolean;
  isQuerys      : Boolean;
  isParameters  : Boolean;
  isContainers  : Boolean;
  isUsers       : Boolean;
  isGroups      : Boolean;

implementation
uses DAO_TLB;
//--------------------------------------------------------------------------
procedure GResetbtypes;
begin
  isFields      := false;
  isRelations   := false;
  isQuerys      := false;
  isEngine      := false;
  isWorkspaces  := false;
  isParameters  := false;
  isDatabases   := false;
  isUsers       := false;
  isGroups      := false;
  isRecordsets  := false;
  isTables      := false;
  isIndexes     := false;
  isContainers  := false;
  isDocuments   := false;
end;  
//--------------------------------------------------------------------------
Function GDataTypeEnum(PDataTypeEnum : Integer) : string;
begin
  Result := ' (?)';
  case PDataTypeEnum of
  { DataTypeEnum }
    dbBoolean    : result := ' (dbBoolean)';
    dbByte       : result := ' (dbByte)';
    dbInteger    : result := ' (dbInteger)';
    dbLong       : result := ' (dbLong)';
    dbCurrency   : result := ' (dbCurrency)';
    dbSingle     : result := ' (dbSingle)';
    dbDouble     : result := ' (dbDouble)';
    dbDate       : result := ' (dbDate)';
    dbBinary     : result := ' (dbBinary)';
    dbText       : result := ' (dbText)';
    dbLongBinary : result := ' (dbLongBinary)';
    dbMemo       : result := ' (dbMemo)';
    dbGUID       : result := ' (dbGUID)';
    dbBigInt     : result := ' (dbBigInt)';
    dbVarBinary  : result := ' (dbVarBinary)';
    dbChar       : result := ' (dbChar)';
    dbNumeric    : result := ' (dbNumeric)';
    dbDecimal    : result := ' (dbDecimal)';
    dbFloat      : result := ' (dbFloat)';
    dbTime       : result := ' (dbTime)';
    dbTimeStamp  : result := ' (dbTimeStamp)';
  end;
end;
//--------------------------------------------------------------------------
Function GRelationAttributeEnum(PRelationAttributeEnum : Integer) : string;
begin
  Result := ' (?)';
  case PRelationAttributeEnum of
{ RelationAttributeEnum }
    dbRelationUnique        : result := ' (dbRelationUnique)';
    dbRelationDontEnforce   : result := ' (dbRelationDontEnforce)';
    dbRelationInherited     : result := ' (dbRelationInherited)';
    dbRelationUpdateCascade : result := ' (dbRelationUpdateCascade)';
    dbRelationDeleteCascade : result := ' (dbRelationDeleteCascade)';
    dbRelationLeft          : result := ' (dbRelationRelationLeft)';
    dbRelationRight         : result := ' (dbRelationRelationRight)';
  end;
end;
//--------------------------------------------------------------------------
Function GFieldAttributeEnum(PFieldAttributeEnum : Integer) : string;
begin
  Result := ' (?)';
  case PFieldAttributeEnum of
{ FieldAttributeEnum }
    dbFixedField            : result := ' (dbFixedField)';
    dbVariableField         : result := ' (dbVariableField)';
    dbAutoIncrField         : result := ' (dbAutoIncrField)';
    dbUpdatableField        : result := ' (dbUpdatableField)';
    dbSystemField           : result := ' (dbSystemField)';
    dbHyperlinkField        : result := ' (dbHyperlinkField)';
    //dbDescending          : result := ' (Descending)'; //same as dbFixedField
  end;
end;
//--------------------------------------------------------------------------
Function GCollatingOrderEnum (PCollatingOrderEnum : Integer) : string;
begin
  Result := ' (?)';
  case PCollatingOrderEnum of
{ CollatingOrderEnum }
     dbSortNeutral           : result := ' (dbSortNeutral)';
     dbSortArabic            : result := ' (dbSortArabic)';
     dbSortCyrillic          : result := ' (dbSortCyrillic)';
     dbSortCzech             : result := ' (dbSortCzech)';
     dbSortDutch             : result := ' (dbSortDutch)';
     dbSortGeneral           : result := ' (dbSortGeneral)';
     dbSortGreek             : result := ' (dbSortGreek)';
     dbSortHebrew            : result := ' (dbSortHebrew)';
     dbSortHungarian         : result := ' (dbSortHungarian)';
     dbSortIcelandic         : result := ' (dbSortIcelandic)';
     dbSortNorwdan           : result := ' (dbSortNorwdan)';
     //dbSortPDXIntl           : result := ' (dbSortPDXIntl)';  //same as dbSortGeneral
     //dbSortPDXNor            : result := ' (dbSortPDXNor)';   //same as dbSortNorwdan
     //dbSortPDXSwe            : result := ' (dbSortPDXSwe)';   //same as dbSortSwedFin
     dbSortPolish            : result := ' (dbdbSortPolish)';
     dbSortSpanish           : result := ' (dbSortSpanish)';
     dbSortSwedFin           : result := ' (dbSortSwedFin)';
     dbSortTurkish           : result := ' (dbSortTurkish)';
     dbSortJapanese          : result := ' (SortJapanese)';
     dbSortChineseSimplified : result := ' (SortChineseSimplified)';
     dbSortChineseTraditional: result := ' (SortChineseTraditional)';
     dbSortKorean            : result := ' (dbSortKorean)';
     dbSortThai              : result := ' (dbSortThai)';
     dbSortSlovenian         : result := ' (dbSortSlovenian)';
     dbSortUndefined         : result := ' (dbSortUndefined)';
  end;
end;
//--------------------------------------------------------------------------
Function GWorkspaceTypeEnum(PWorkspaceTypeEnum : Integer) : string;
begin
  Result := ' (?)';
  case PWorkspaceTypeEnum of
  { WorkspaceTypeEnum }
     dbUseODBC : result := ' (dbUseODBC)';
     dbUseJet  : result := ' (dbUseJet)';
  end;
end;
//--------------------------------------------------------------------------
Function GParameterDirectionEnum (PParameterDirectionEnum : Integer) : string;
begin
  Result := ' (?)';
  case PParameterDirectionEnum of
{ ParameterDirectionEnum }
    dbParamInput       : result := ' (dbParamInput)';
    dbParamOutput      : result := ' (dbParamOutput)';
    dbParamInputOutput : result := ' (dbParamInputOutput)';
    dbParamReturnValue : result := ' (dbParamReturnValue)';
  end;
end;
//--------------------------------------------------------------------------
Function GUpdateTypeEnum(PUpdateTypeEnum : Integer) : string;
begin
  Result := ' (?)';
  case PUpdateTypeEnum of
{ UpdateTypeEnum }
    dbUpdateBatch         : result := ' (dbUpdateBatch)';
    dbUpdateRegular       : result := ' (dbUpdateRegular)';
    dbUpdateCurrentRecord : result := ' (dbUpdateCurrentRecord)';
   end;
end;
//--------------------------------------------------------------------------
Function GRecordStatusEnum(PRecordStatusEnum : Integer) : string;
begin
  Result := ' (?)';
  case PRecordStatusEnum of
 { RecordStatusEnum }
    dbRecordUnmodified : result := ' (dbRecordUnmodified)';
    dbRecordModified   : result := ' (dbRecordModified)';
    dbRecordNew        : result := ' (dbRecordNew)';
    dbRecordDeleted    : result := ' (dbRecordDeleted)';
    dbRecordDBDeleted  : result := ' (dbRecordDBDeleted)';
  end;
end;
//--------------------------------------------------------------------------
Function GQueryDefTypeEnum(PQueryDefTypeEnum : Integer) : string;
begin
  Result := ' (?)';
  case PQueryDefTypeEnum of
  {QueryDefTypeEnum}
    dbQSelect         : result := ' (dbQSelect)';
    dbQProcedure      : result := ' (dbQProcedure)';
    dbQAction         : result := ' (dbQAction)';
    dbQCrosstab       : result := ' (dbQCrosstab)';
    dbQDelete         : result := ' (dbQDelete)';
    dbQUpdate         : result := ' (dbQUpdate)';
    dbQAppend         : result := ' (dbQAppend)';
    dbQMakeTable      : result := ' (dbQMakeTable)';
    dbQDDL            : result := ' (dbQDDL)';
    dbQSQLPassThrough : result := ' (dbQSQLPassThrough)';
    dbQSetOperation   : result := ' (dbQSetOperation)';
    dbQSPTBulk        : result := ' (dbQSPTBulk)';
    dbQCompound       : result := ' (dbQCompound)';
  end;
end;
//--------------------------------------------------------------------------
//The string '\StringFileInfo\040904E4\' is for a U.S. character set.{...}
function GetVersionNumber(VerString : string) : String;
var
  AppExe: String;
  AppInfoSize,Len : DWORD;
  Buf   : PChar;
  Value : PChar;
begin
    Result := '';
    AppExe := Application.ExeName;
    AppInfoSize := GetFileVersionInfoSize(PChar(AppExe),AppInfoSize);
    if AppInfoSize > 0 then
      begin
         Buf := AllocMem(AppInfoSize);
         try
           GetFileVersionInfo(PChar(AppExe),0,AppInfoSize,Buf);
           if VerQueryValue(Buf,
                            PChar('StringFileInfo\040904E4\' + Verstring),
                            Pointer(Value),
                            Len) then
              Result := String(Value);
         except
           result := 'Cant read fileinfo';
         end;
         FreeMem(Buf,AppInfoSize);
     end;
end;
end.
